#-*-coding:utf-8*-*
"""
Tests liés à la migration de variables
"""
from os.path import join, isfile
from creole.loader import creole_loader

CONFIG_DIR = '/usr/share/creole/tests/configs'
DICO_DIR = '/usr/share/eole/creole/dicos'

def _calc_config_file(test):
    """
    nom du fichier eol lié au test
    """
    return join(CONFIG_DIR, '{0}.eol'.format(test))

def _get_value(config, variable):
    """
    Retourne la valeur d'une variable "connue"
    """
    path = config.find_first(byname=variable, type_='path')
    return config.getattr(path, force_permissive=True)

def test_upgrade_hosts_from23():
    """
    Vérifie la migration des variables "activer_ajout_hosts"
    depuis une configuration 2.3 contenant des majuscules #11473
    et un doublon sur le nom court #12266
    """
    config = creole_loader(force_configeol=_calc_config_file('hosts23'))
    assert _get_value(config, 'activer_ajout_hosts') == 'oui'
    assert _get_value(config, 'nom_court_hosts') == ['min', 'maj', 'wpad', None]
    assert _get_value(config, 'nom_long_hosts') == ['min.min', 'maj.maj', 'wpad.admin.lan', 'wpad.pedago.lan']

def test_upgrade_scribe_dmz():
    """
    Vérifie la migration de la variable "install_scribe_dmz"
    en fonction du remplissage des esclaves associées #11713
    ce test n'est pas compatible avec AmonEcole #11796
    """
    if isfile(join(DICO_DIR, '10_era.xml')) and not isfile(join(DICO_DIR, '50_amonecole.xml')):
        config = creole_loader(force_configeol=_calc_config_file('scribe_dmz_ok'))
        assert _get_value(config, 'install_scribe_dmz') == 'oui'
        config = creole_loader(force_configeol=_calc_config_file('scribe_dmz_ko'))
        assert _get_value(config, 'install_scribe_dmz') == 'non'

def test_serveur_maj():
    """
    Vérifie la migration de la variable serveur_maj
    Les serveurs officiels doivent être renommés
    """
    config = creole_loader(force_configeol=_calc_config_file('maj23'))
    assert _get_value(config, 'serveur_maj') == ['test-eole.ac-dijon.fr', 'eole.ac-dijon.fr', 'eoleng.ac-test.fr', 'ftp.crihan.fr']


#####################################
# tests spécifiques à EOLE >= 2.4.2 #
#####################################

def test_upgrade_force_envole():
    """
    Vérifie la valeur de la redirection par défaut "web_redirection"
    dans le cas où Envole était activé #11582
    test modifié suite à la suppression de la variable alias_envole #10549
    """
    if isfile('/usr/share/eole/creole/dicos/20_web.xml'):
        config = creole_loader(force_configeol=_calc_config_file('envole'))
        if isfile('/usr/share/eole/creole/dicos/21_posh.xml'):
            assert _get_value(config, 'web_redirection') == u'/envole'
        else:
            assert _get_value(config, 'web_redirection') == u'/testenvole'


#####################################
# tests spécifiques à EOLE >= 2.5.0 #
#####################################

def test_upgrade_nut_monitor():
    """
    Vérifie l'activation de la variable "nut_monitor"
    si un onduleur esclave était déclaré #11608
    """
    config = creole_loader(force_configeol=_calc_config_file('onduleur24'))
    assert _get_value(config, 'nut_monitor') == u'oui'

def test_upgrade_postgresql():
    """
    Vérifie la mise à jour des variables postgeSQL #11222
    """
    if isfile('/usr/share/eole/creole/dicos/22_postgresql.xml'):
        config = creole_loader(force_configeol=_calc_config_file('postgres23_default'))
        assert _get_value(config, 'pg_shared_buffers') == 128
        assert _get_value(config, 'pg_shared_buffers_unit') == u'MB'
        config = creole_loader(force_configeol=_calc_config_file('postgres23_modif'))
        assert _get_value(config, 'pg_shared_buffers') == 6000
        assert _get_value(config, 'pg_shared_buffers_unit') == u'kB'


#####################################
# tests spécifiques à EOLE >= 2.5.1 #
#####################################

def test_upgrade_zone_forward():
    """
    Vérifie l'activation de la variable "activer_zone_forward"
    si des zones étaient déclarées #11922
    """
    if isfile('/usr/share/eole/creole/dicos/22_dns.xml'):
        config = creole_loader(force_configeol=_calc_config_file('zone_forward24'))
        assert _get_value(config, 'activer_zone_forward') == u'oui'

def test_upgrade_bareos_from23():
    """
    Valide le renommage des variables bacula en bareos
    entre 2.3 et 2.5.1 #13957
    """
    if isfile('/usr/share/eole/creole/dicos/23_bareos.xml'):
        config = creole_loader(force_configeol=_calc_config_file('bacula23'))
        assert _get_value(config, 'bareos_full_retention') == 13

def test_upgrade_amon23():
    """
    Valide que la migration des variables "etb1.amon" va à son terme #14589
    """
    if isfile('/usr/share/eole/creole/dicos/30_amon.xml'):
        config = creole_loader(force_configeol=_calc_config_file('amon23'))
        assert config.impl_get_information('upgrade', False) == '2.3'


#####################################
# tests spécifiques à EOLE >= 2.5.2 #
#####################################

def test_upgrade_sphynxhamaster():
    """
    Valide la migration des variables haute-dispo
    sur le master #14881
    """
    if isfile('/usr/share/eole/creole/dicos/30_sphynx.xml'):
        config = creole_loader(force_configeol=_calc_config_file('hamaster241'))
        assert _get_value(config, 'vip_externe') == '192.168.0.10'
        assert _get_value(config, 'vip_interne') == '172.30.101.10'
        assert _get_value(config, 'vip_resource_netmask') == ['255.255.255.0', '255.255.255.0']
        assert _get_value(config, 'vip_resource_gw') == ['192.168.0.1', '255.255.255.255']
        assert _get_value(config, 'service_resource_name') == [u'ipsec_rsc', u'arv_rsc']
        assert _get_value(config, 'service_resource_script') == [u'ipsecSphynx', u'arv']
        assert _get_value(config, 'service_resource_arv_startdelay') == 30
        assert _get_value(config, 'service_resource_startdelay') == [15, 30]
        assert _get_value(config, 'activer_resource_arv') == u'oui'

